import { useEffect, useState } from 'react';
/**
 *
 * @Author Casey Bui
 * @Email buikhacnam11@gmail.com
 * @Github https://github.com/buikhacnam
 * @License MIT
 */
export function useUrlFilter(params, apiUrl, refreshParams) {
    const url = new URL(window.location.href);
    const query = url.searchParams;
    const [apiQuery, setApiQuery] = useState(apiUrl);
    const [queryString, setQueryString] = useState('');
    useEffect(() => {
        const recentQuery = '?' + query.toString();
        setQueryString(recentQuery);
        setApiQuery(apiUrl + recentQuery);
        window.addEventListener('popstate', function (e) {
            window.location.reload();
        });
    }, []);
    const handleSelectFilter = (name, value) => {
        const filter = convertParamsToFilterObject(params);
        filter[name] = value;
        if (refreshParams && (refreshParams === null || refreshParams === void 0 ? void 0 : refreshParams.length) > 0 && !refreshParams.includes(name)) {
            refreshParams.forEach((param) => {
                filter[param] = '';
            });
        }
        const query = buildQuery(params, filter);
        setApiQuery(apiUrl + query);
        setQueryString(query);
        window.history.pushState({}, '', query);
    };
    const buildQuery = (params, filter) => {
        let url = '?';
        params.forEach((param) => {
            url += `&${param}=${filter[param]}`;
        });
        return url.replace('&', '');
    };
    const convertParamsToFilterObject = (params) => {
        const filter = {};
        params.forEach((param) => {
            filter[param] = query.get(param) || '';
        });
        return filter;
    };
    const getDefaultParamValue = (params, defaultValue) => {
        return query.get(params) || defaultValue;
    };
    return {
        apiQuery,
        queryString,
        getDefaultParamValue,
        handleSelectFilter
    };
}
//# sourceMappingURL=index.js.map